SchemaSpy - Table gnss_data.public.rinex

Tables Relationships Utility Tables Constraints Anomalies Columns Donate

Table gnss_data.public.rinex | Generated by SchemaSpy

Related columns Constraints Comments Legend |
Legend: |
Primary key columns
Columns with indexes
Implied relationships
Excluded column relationships
< n > number of related tables
Column | Type | Size | Nulls | Auto | Default | Children | Parents | Comments
--- | --- | --- | --- | --- | --- | --- | --- | ---
NetworkCode | varchar | 2147483647 |  |  |  |
gamit_soln.NetworkCode | gamit_soln_NetworkCode_fkey1 R
ppp_soln.NetworkCode | ppp_soln_NetworkCode_fkey R
stations.NetworkCode | rinex_NetworkCode_fkey R
StationCode | varchar | 2147483647 |  |  |  |
gamit_soln.StationCode | gamit_soln_NetworkCode_fkey1 R
ppp_soln.StationCode | ppp_soln_NetworkCode_fkey R
stations.StationCode | rinex_NetworkCode_fkey R
ObservationYear | numeric | 131089 |  |  |  |
gamit_soln.Year | gamit_soln_NetworkCode_fkey1 R
ppp_soln.Year | ppp_soln_NetworkCode_fkey R
ObservationMonth | numeric | 131089 |  |  |  |  |  |
ObservationDay | numeric | 131089 |  |  |  |  |  |
ObservationDOY | numeric | 131089 |  |  |  |
gamit_soln.DOY | gamit_soln_NetworkCode_fkey1 R
ppp_soln.DOY | ppp_soln_NetworkCode_fkey R
ObservationFYear | numeric | 131089 |  |  |  |  |  |
ObservationSTime | timestamp | 29,6 | √ |  | null |  |  |
ObservationETime | timestamp | 29,6 | √ |  | null |  |  |
ReceiverType | varchar | 20 | √ |  | null |  |  |
ReceiverSerial | varchar | 20 | √ |  | null |  |  |
ReceiverFw | varchar | 20 | √ |  | null |  |  |
AntennaType | varchar | 20 | √ |  | null |  |  |
AntennaSerial | varchar | 20 | √ |  | null |  |  |
AntennaDome | varchar | 20 | √ |  | null |  |  |
Filename | varchar | 20 | √ |  | null |  |  |
Interval | numeric | 131089 | √ |  | null |  |  |
AntennaOffset | numeric | 131089 | √ |  | null |  |  |
Table contained 726,860 rows at Fri Jul 28 14:55 EDT 2017

Close relationships within one two degrees of separation: